@@ -13,7 +13,7 @@
 ##############################################################################
 """ZCML Implementation to populate base registries.
 
-$Id: zcml.py 94694 2009-01-12 13:07:00Z nadako $
+$Id: zcml.py 107148 2009-12-27 09:03:32Z fafhrd $
 """
 __docformat__ = "reStructuredText"
 import zope.interface
@@ -21,15 +21,14 @@ import zope.component.globalregistry
 import zope.configuration.config
 import zope.configuration.fields
 from zope.configuration.exceptions import ConfigurationError
-from zope.i18nmessageid import ZopeMessageFactory as _
 
 
 class IRegisterInDirective(zope.interface.Interface):
     """Use the specified registry for registering the contained components."""
 
     registry = zope.configuration.fields.GlobalObject(
-        title=_("Registry"),
-        description=_("Python path to the registry to use."),
+        title=u"Registry",
+        description=u"Python path to the registry to use.",
         required=True)
 
 
@@ -113,4 +112,3 @@ class RegisterIn(zope.configuration.config.GroupingContextDecorator):
             callable=resetOriginalRegistry,
             args=(self,)
             )
-
